from typing import Dict, List

from civitai_dl.api.client import CivitaiAPI
from civitai_dl.core.downloader import DownloadEngine
from civitai_dl.utils.config import get_config


class ModelSearcher:
    """模型搜索器组件，提供模型搜索和浏览功能"""

    def __init__(self, api: CivitaiAPI, downloader: DownloadEngine):
        """初始化模型搜索器"""
        self.api = api
        self.downloader = downloader
        self.config = get_config()
        self.current_results = []  # 当前搜索结果

    def search_models(
        self,
        query: str,
        model_types: List[str] = None,
        sort: str = "Highest Rated",
        nsfw: bool = False,
        page: int = 1,
        page_size: int = 20,
    ) -> Dict:
        """
        搜索模型

        Args:
            query: 搜索关键词
            model_types: 模型类型列表
            sort: 排序方式
            nsfw: 是否包括NSFW内容
            page: 页码
            page_size: 每页结果数量

        Returns:
            搜索结果字典
        """
        try:
            # TODO: 实际实现应该调用API进行搜索
            # 目前返回模拟数据用于UI开发
            results = [
                [12345, "示例模型 1", "LORA", "创作者A", 1250, 4.8],
                [67890, "示例模型 2", "Checkpoint", "创作者B", 3400, 4.5],
                [54321, "示例模型 3", "TextualInversion", "创作者C", 800, 4.2],
            ]

            # 保存当前结果
            self.current_results = results

            return {"data": results, "total": len(results), "page": page}

        except Exception as e:
            return {"data": [], "error": str(e), "total": 0, "page": page}

    def download_selected(self, selected_indices: List[int]) -> str:
        """
        下载选中的模型

        Args:
            selected_indices: 选中结果的索引列表

        Returns:
            操作结果信息
        """
        if not selected_indices or not self.current_results:
            return "未选择任何模型或没有搜索结果"

        try:
            # TODO: 实现下载选中模型的逻辑
            selected_models = [
                self.current_results[i]
                for i in selected_indices
                if i < len(self.current_results)
            ]
            model_ids = [model[0] for model in selected_models]

            return f"将下载选中的 {len(model_ids)} 个模型: {', '.join(map(str, model_ids))}"

        except Exception as e:
            return f"下载选中模型时出错: {str(e)}"
